/* Copyright (C) 2004 Per Johansson
	
	This file is part of netGo.

    netGo is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    netGo is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with netGo; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <qobject.h>
#include <qregexp.h>
#include <qpixmap.h>
#include <qprocess.h>

#include "netgodialogbase.h"
#include "process.h"

#ifndef NETGODIALOG_H
#define NETGODIALOG_H

// Subclassing netGoDialogBase
class netGoDialog : public netGoDialogBase
{
	Q_OBJECT
			
	public:
		// Constructor for the GUI.
		netGoDialog(QWidget *parent, const char *name);
		
		// Constructor for the commandline mode.
		netGoDialog(const char *profile);

	public slots:
		void mainPage();
		void addProfilePage();
		void morePage();		
		void runProfilePage();
		void editProfilePage();
		void editMorePage();
		void deleteProfilePage();
		
		void enableMainGoBut();
		void enableEditProfileBut();
		void enableDeleteProfileBut();
		
		void addProfile();
		void deleteProfile(const QString &profile);
		void editProfile();
		
		void fillEditProfilePage();
		void clearAddProfile();
		void updateProfiles();
		void cancelRunProfile();
		
		void cmdlineExecution(const char *profile);
		void exitCmdline();
		
		void updateIfaces();
	
	private:
		// The process object that executes the network settings.
		Process *networkProc;
		QProcess *fetchIfaces;
		
		// Pixmap used in the profile listbox.
		QPixmap standardIco;
		
		// Regular expressions.
		QRegExp common;
		QRegExp ip;
		QRegExp ipOrDhcp;
		QRegExp proxy;
		QRegExp ifacesDown;

		// Stringlist containing all the interfaces on the system.
		QStringList ifaces;
};

#endif
