/* Copyright (C) 2004 Per Johansson
	
	This file is part of netGo.

    netGo is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    netGo is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with netGo; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <qstring.h>
#include <qdir.h>
#include <qfile.h>
#include <qmessagebox.h>
#include <qvaluevector.h>
#include <qstringlist.h>
#include <qregexp.h>

#include "profile.h"

// Allocate memory for this static variable and make it global.
QValueVector<Profile> Profile::profiles;

// Default constructor for class-Profile.
Profile::Profile()
{
}

// Function for importing all the profiles from the
// textfile (profiles.txt) and saving each of them in a vector.
void Profile::fetchProfiles()
{
	// Remove the old profiles from the vector.
	profiles.clear();
	
	// Cd to the data-directory.
	QDir dir = QDir::current();
	if (!dir.cd("data/")) {
		qWarning("Could not find the data-dir.");
		QMessageBox::critical(0, "Data-directory", "Couldn't find, or open the data-directory.");
		return;
	}
	
	// Open profiles.txt for reading.
	QFile file(dir.filePath("profiles.txt"));
	if (!file.open(IO_ReadOnly)) {
		qWarning("Could not find profiles.txt");
		QMessageBox::critical(0, "profiles.txt", "Couldn't find, or open profiles.txt.");
		return;
	}
	
	// Create all the neccesery variables.
	QTextStream textfile(&file);
	QString row;
	
	// Regexp for fetching the network settings.
	QRegExp profile("^([^# ]+)#([^# ]*)#([^# ]*)#([^# ]*)#([^# ]*)#([^# ]*)#([^# ]*)#([^# ]*)#([^# ]*)#([^# ]*)#([^# ]*)#$");
	
	// Loop through profiles.txt and save each profile in an object.
	while (!file.atEnd() ) {
		
		// Create an object to save the profile in.
		Profile temp; 
		
		// Save each line.
		textfile >> row;
		
		// Let the regexp search through the line.
		if (profile.search(row) != -1) {
			
			// Save all the network settings in the object.
			temp.name = profile.cap(1);
			temp.iface = profile.cap(2);
			temp.ip = profile.cap(3);
			temp.netmask = profile.cap(4);
			temp.gw = profile.cap(5);
			temp.ns1 = profile.cap(6);
			temp.ns2 = profile.cap(7);
			temp.search = profile.cap(8);
			temp.mode = profile.cap(9);
			temp.essid = profile.cap(10);
			temp.key = profile.cap(11);
			
			// Insert the object/profile in the profile vector.
			profiles.push_back(temp);
		}
		else
			qWarning("The profile didn't have a valid structure. Skipping.");
	}		
}

// Debug-function for dumping info about a profile.
void Profile::dumpProfiles()
{
	int i;
	for (i=0; i<profiles.size(); i++) 
		qWarning("\n\nName: " + profiles.at(i).name);
}
