/* Copyright (C) 2004 Per Johansson
	
	This file is part of netGo.

    netGo is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    netGo is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with netGo; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <qstring.h>
#include <qstringlist.h>
#include <qdir.h>
#include <qfile.h>
#include <qregexp.h>
#include <qmessagebox.h>

#include "settings.h"

// Allocate memory for the variables and make them global.
QString Settings::IFCONFIG_PATH = "";
QString Settings::ROUTE_PATH = "";
QString Settings::IWCONFIG_PATH = "";
QString Settings::DHCP_CLIENT_PATH = "";
QString Settings::DHCP_CLIENT = "";

// Default constructor.
Settings::Settings()
{
}

// Function that checks if there are any user settings
// specified in settings.txt. Returns true if there's settings.
bool Settings::fetchSettings()
{
	// Cd to the data-dir.
	QDir dir = QDir::current();
	if (!dir.cd("data/")) {
		qWarning("Could not find the data-dir.");
		QMessageBox::critical(0, "Data-directory", "Couldn't find, or open the data-directory.");
		return false;
	}
	
	// Open settings.txt - for reading.
	QFile file(dir.filePath("settings.txt") );
	
	// If settings.txt doesn't exist - return false.
	if (!file.open(IO_ReadOnly))
		return false;
	else 
	{
		// If settings.txt allready exists we need to check
		// that the settings are valid.
		
		// Create some regexps that validates the settings.
		QRegExp ifconfig("^ifconfig:(/.+)");
		QRegExp route("^route:(/.+)");
		QRegExp iwconfig("^iwconfig:(/.+)");
		QRegExp dhcpClientPath("^dhcp-client:(/.+)");
		QRegExp dhcpClient("/([^/]+)$");
		
		QTextStream settings(&file);
		QString row1, row2, row3, row4;
	
		// Read the first line (ifconfig).
		settings >> row1;
		
		// Check that the line contains "ifconfig:".
		if (ifconfig.search(row1) != -1)
			IFCONFIG_PATH = ifconfig.cap(1);
		else {
			qWarning("Invalid settings on the first line.");
			return false;
		}
		
		// Read the second line (route).
		settings >> row2;
		
		// Check that the line contains "route:".
		if (route.search(row2) != -1)
			ROUTE_PATH = route.cap(1);
		else {
			qWarning("Invalid settings on the second line.");
			return false;
		}
		
		
		// Read the third line (iwconfig).
		settings >> row3;
		
		// Check that the line contains "iwconfig:".
		if (iwconfig.search(row3) != -1)
			IWCONFIG_PATH = iwconfig.cap(1);
		else {
			qWarning("Invalid settings on the third line.");
			return false;
		}
		
		// Read the fourth line (dhcp client).
		settings >> row4;
		
		// Check that the line contains "dhcp-client:".
		if (dhcpClientPath.search(row4) != -1 && dhcpClient.search(row4) != -1) {
			DHCP_CLIENT_PATH = dhcpClientPath.cap(1);
			DHCP_CLIENT = dhcpClient.cap(1);
		}
		else {
			qWarning("Invalid settings on the fourth line.");
			return false;
		}			
	}
	
	// If the function hasn't failed, return true.
	return true;
}

// Debug function that dumps all the settings.
void Settings::dumpSettings()
{
	qWarning("ifconfig path: " + IFCONFIG_PATH + "\n"
			"route path: " + ROUTE_PATH + "\n"
			"iwconfig path: " + IWCONFIG_PATH + "\n"
			"dhcp-client: " + DHCP_CLIENT + "\n"
			"dhcp-client path: " + DHCP_CLIENT_PATH);
}
